@@ -1,20 +1,21 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2006-2007 Kevin Ottens <ervin@kde.org>
+/*
+    Copyright 2006-2007 Kevin Ottens <ervin@kde.org>
 
     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    Lesser General Public License for more details.
 
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef SOLID_DEVICEINTERFACE_H
@@ -51,8 +52,9 @@ namespace Solid
          * - Unknown : An undetermined device interface
          * - Processor : A processor
          * - Block : A block device
+         * - StorageAccess : A mechanism to access data on a storage device
          * - StorageDrive : A storage drive
-         * - Cdrom : A CD-ROM drive
+         * - OpticalDrive : An optical drive (CD-ROM, DVD, ...)
          * - StorageVolume : A volume
          * - OpticalDisc : An optical disc
          * - Camera : A digital camera
@@ -60,6 +62,7 @@ namespace Solid
          * - NetworkInterface: A network interface
          * - SerialInterface: A serial interface
          * - SmartCardReader: A smart card reader interface
+         * - NetworkShare: A network share interface
          */
         enum Type { Unknown = 0, GenericInterface = 1, Processor = 2,
                     Block = 3, StorageAccess = 4, StorageDrive = 5,
@@ -67,8 +70,8 @@ namespace Solid
                     Camera = 9, PortableMediaPlayer = 10,
                     NetworkInterface = 11, AcAdapter = 12, Battery = 13,
                     Button = 14, AudioInterface = 15, DvbInterface = 16, Video = 17,
-                    SerialInterface = 18, SmartCardReader = 19,
-                    Last = 0xffff  };
+                    SerialInterface = 18, SmartCardReader = 19, InternetGateway = 20,
+                    NetworkShare = 21, Last = 0xffff  };
 
         /**
          * Destroys a DeviceInterface object.
